@@ -11,7 +11,7 @@ from typing import Any, Dict, List
 import click
 
 import solitude.core
-from solitude.core import log_setup
+from solitude.core import log_setup, get_connected_ssh_client_from_config
 from solitude.config import get_config
 from solitude.cache import json_write_atomic
 from solitude import TOOL_NAME, __version__
@@ -302,7 +302,12 @@ def link(
     cmd_files: List[Path], jobids: List[int], workers: int, slurm_jobid: int
 ):
     if are_jobids_specified(jobids=jobids) and is_config_valid():
-        if SlurmJob.check_if_job_exists(jobid=slurm_jobid):
+        ssh_client = get_connected_ssh_client_from_config(
+            cfg=get_config(), verbose=False
+        )
+        if SlurmJob.check_if_job_exists(
+            ssh_client=ssh_client, jobid=slurm_jobid
+        ):
             for jobid in jobids:
                 success = solitude.core.link(
                     cmd_files=cmd_files,
