@@ -230,19 +230,35 @@ def link(
     cfg: Config,
     cache_file: Path,
 ) -> bool:
+    ssh_client = get_connected_ssh_client_from_config(cfg, verbose=False)
+
     commands, cache, _ = shared_section(
         cmd_files=cmd_files, cache_file=cache_file, cfg=cfg
     )
     cmd = commands[jobid - 1]
     # link jobid to slurm_jobid
-    if SlurmJob.check_if_job_exists(jobid=slurm_jobid):
-        job = SlurmJob(jobid=slurm_jobid)
+    if SlurmJob.check_if_job_exists(ssh_client=ssh_client, jobid=slurm_jobid):
+        job = SlurmJob(ssh_client=ssh_client, jobid=slurm_jobid)
         job.update()
         cache.update(key=cmd.hash, value=job)
         return True
     return False
 
 
+def get_connected_ssh_client_from_config(
+    cfg: Config, verbose: bool = True
+) -> ssh.SSHClient:
+    ssh_client = ssh.SSHClient(verbose=verbose)
+    if cfg.ssh is None:
+        logger.error(
+            "SSH credentials are not configured in the solitude configuration file."
+            "Run `solitude config create` to setup the credentials."
+        )
+        sys.exit(1)
+    ssh_client.connect(*cfg.ssh)
+    return ssh_client
+
+
 def unlink(cmd_files: List[Path], jobid: int, cfg, cache_file: Path) -> bool:
     commands, cache, _ = shared_section(
         cmd_files=cmd_files, cache_file=cache_file, cfg=cfg
@@ -263,9 +279,7 @@ def _run_command_on_running_job(
     command: str,
     action_str: str,
 ):
-    ssh_client = ssh.SSHClient()
-    assert cfg.ssh is not None
-    ssh_client.connect(*cfg.ssh)
+    ssh_client = get_connected_ssh_client_from_config(cfg=cfg, verbose=False)
 
     commands, _, credentials = shared_section(
         cmd_files=cmd_files, cache_file=cache_file, cfg=cfg
@@ -275,11 +289,12 @@ def _run_command_on_running_job(
     subcmds = [cmd for idx, cmd in enumerate(commands) if idx + 1 in jobids]
 
     def _update_cmd(cmd):
-        cmd.update_job_info()
+        cmd.update_job_info(ssh_client=ssh_client)
 
     execute_commands(
         subcmds, map_fn=_update_cmd, workers=workers, show_progress_bar=True
     )
+    ssh_client.verbose = True
 
     for idx, cmd in zip(jobids, subcmds):
         if cmd.is_running():
@@ -300,6 +315,8 @@ def list_jobs(
     selected_only: bool = False,
     show_progress_bar: bool = True,
 ):
+    ssh_client = get_connected_ssh_client_from_config(cfg=cfg, verbose=False)
+
     commands, _, _ = shared_section(
         cmd_files=cmd_files, cache_file=cache_file, cfg=cfg
     )
@@ -315,7 +332,7 @@ def list_jobs(
     ]
 
     def _update_cmd(cmd):
-        cmd.update()
+        cmd.update(ssh_client=ssh_client)
 
     execute_commands(
         subcmds,
@@ -346,16 +363,14 @@ def run(
     cfg: Config,
     cache_file: Path,
 ):
-    ssh_client = ssh.SSHClient()
-    assert cfg.ssh is not None
-    ssh_client.connect(*cfg.ssh)
+    ssh_client = get_connected_ssh_client_from_config(cfg=cfg, verbose=False)
 
     commands, cache, credentials = shared_section(
         cmd_files=cmd_files, cache_file=cache_file, cfg=cfg
     )
 
     def _update_cmd(cmd):
-        cmd.update_job_info()
+        cmd.update_job_info(ssh_client=ssh_client)
 
     execute_commands(
         commands, map_fn=_update_cmd, workers=workers, show_progress_bar=False
@@ -388,6 +403,7 @@ def run(
     execute_commands(
         subcmds, map_fn=_update_cmd2, workers=workers, show_progress_bar=True
     )
+    ssh_client.verbose = True
 
     for idx, cmd in zip(jobids, subcmds):
         logger.info(f"ATTEMPT EXECUTE Job {idx}")
@@ -448,13 +464,17 @@ def run(
                                 "Assigned a high priority job switching to low priority now"
                             )
                             priority = "low"
-                        logger.info(f"http://oni:11080/show/{link_id}")
                     else:
+                        ssh_server_name = (
+                            cfg.ssh.server
+                            if cfg.ssh is not None
+                            else "not-set"
+                        )
                         logger.error(
                             f"ERROR - Unexpected c-submit output received: `{cmd_output}`. "
                             f"The command is likely not scheduled. "
                             f"Check if the `c-submit` command works on the configured "
-                            f"ssh-server: `{cfg.ssh.server}` or change the target "
+                            f"ssh-server: `{ssh_server_name}` or change the target "
                             f"ssh-server in your configuration."
                         )
             except Exception as e:
