@@ -1,19 +1,27 @@
 import re
-from typing import Dict, List
+from typing import Dict, List, Optional
 from solitude import hookimpl
 
 
-def filter_csubmit_command_str(cmd: str) -> str:
-    result = re.search(
-        r"c-submit\s+(?:--[\S-]+(?:=\S+)?\s+)*[\S]+\s+\S+\s\d+\s(\S+)(.*)",
+def match_csubmit_command_str(cmd: str) -> Optional[re.Match]:
+    return re.search(
+        r"c-submit\s+(?:(?:--\S+(?:\s*[=\s]\s*\S+)?\s+)*)?(?P<user>\S+)"
+        r"\s+(?P<ticket>\S+)\s+(?P<duration>\d+)\s+(?P<image>\D\S+)\s*(?P<args>.*)",
         cmd.strip(),
     )
-    return (result.groups()[0] + result.groups()[1]).strip()
+
+
+def filter_csubmit_command_str(cmd: str) -> str:
+    result = match_csubmit_command_str(cmd=cmd)
+    assert result is not None
+    return (
+        result.groupdict()["image"] + " " + result.groupdict()["args"]
+    ).strip()
 
 
 @hookimpl
 def matches_command(cmd: str) -> bool:
-    return "c-submit " in cmd
+    return match_csubmit_command_str(cmd=cmd) is not None
 
 
 @hookimpl
