@@ -3,12 +3,17 @@ from solitude import hookimpl
 from solitude.plugins.csubmit import (
     get_errors_from_log as _get_errors_from_log,
 )
-from solitude.plugins.csubmit import filter_csubmit_command_str
+from solitude.plugins.csubmit import (
+    filter_csubmit_command_str,
+    match_csubmit_command_str,
+)
 
 
 @hookimpl
 def matches_command(cmd: str) -> bool:
-    return ("c-submit " in cmd) and ("--interactive" in cmd)
+    return (" --interactive " in cmd) and (
+        match_csubmit_command_str(cmd=cmd) is not None
+    )
 
 
 @hookimpl
