@@ -6,13 +6,14 @@ import paramiko
 
 
 class SSHClient(object):
-    def __init__(self, exit_on_fail=True):
+    def __init__(self, exit_on_fail=True, verbose=True):
         self.logger = logging.getLogger(type(self).__name__)
         self._exit_on_fail = exit_on_fail
         self._ssh = paramiko.SSHClient()
         self._ssh.load_system_host_keys()
         self._ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
         self._connected = False
+        self.verbose = verbose
 
     def connect(self, server, username, password) -> bool:
         try:
@@ -46,7 +47,8 @@ class SSHClient(object):
         if not self.is_connected():
             if not self.connect():
                 return None
-        self.logger.info("CMD: {}".format(cmd_to_execute))
+        if self.verbose:
+            self.logger.info("CMD: {}".format(cmd_to_execute))
         try:
             ssh_stdin, ssh_stdout, ssh_stderr = self._ssh.exec_command(
                 cmd_to_execute
@@ -55,7 +57,8 @@ class SSHClient(object):
                 "".join(ssh_stdout.readlines()),
                 "".join(ssh_stderr.readlines()),
             )
-            self.logger.info("RESULT: {}".format(result[0]))
+            if self.verbose:
+                self.logger.info("RESULT: {}".format(result[0]))
             return result
         except Exception as e:
             self.logger.error("Failed with: {}".format(e))
